***Last Updated: 1/24/2017 using Stata14
/*==========================================*
Paper:			For Better or for Worse: Education and the Prevalence of Domestic Violence in Turkey

Purpose:        Produce the Simes adjusted p-values for the estimates generated by the 3a Tables.do

To re-run our analysis, please install a folder "Domestic Violence". There should be 5 subfolders in order for do-files to run:

"originals"
"created"
"do files"
"graphs"
"output"

Before you run this do file, please change the path of the working directory in line 24 and run all of the data cleaning do files.
*==========================================*/

clear
set more off 
set matsize 8000
cap log close
#delimit ;

global dir="XXX\Domestic Violence";
cd "$dir";

use "created/women_data_for_analysis.dta", clear;
log using "output/results.log", replace;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";


*SIMES CORRECTED P-VALUES;
****************** TABLE 2 - Panel A;
*linear RD, h bandwidth, with controls;
foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw), vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2a_linear_h.xls", replace;

*quadratic RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif, bwselect(IK);
regress `x' after1986 di1* di2* $contr1 [aw=womenweight] if abs(dif)<e(h_bw), vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2a_quad_h.xls", replace;

*linear RD, h/2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw)/2, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2a_linear_h2.xls", replace;

*linear RD, h*2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw)*2, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2a_linear_2h.xls", replace;

****************** TABLE 2 - Panel B;
*linear RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2b_linear_h.xls", replace;

*quadratic RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* di2* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2b_quad_h.xls", replace;

*linear RD, h/2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw)/2 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2b_linear_h2.xls", replace;

*linear RD, h*2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw)*2 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t2b_linear_2h.xls", replace;

****************** TABLE 3 - Panel A;
*linear RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3a_linear_h.xls", replace;

*quadratic RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* di2* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3a_quad_h.xls", replace;

*linear RD, h/2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw)/2 & rel==1& rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3a_linear_h2.xls", replace;

*linear RD, h*2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool {;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw)*2 & rel==1& rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3a_linear_2h.xls", replace;

****************** TABLE 3 - Panel B;
*linear RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;

rdrobust `x' dif if rel==1& rural_pre12==0, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3b_linear_h.xls", replace;

*quadratic RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;

rdrobust `x' dif if rel==1& rural_pre12==0, bwselect(IK);
regress `x' after1986 di1* di2* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3b_quad_h.xls", replace;

*linear RD, h/2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;

rdrobust `x' dif if rel==1& rural_pre12==0, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw)/2 & rel==1& rural_pre12==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3b_linear_h2.xls", replace;

*linear RD, h*2 bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool {;

rdrobust `x' dif if rel==1& rural_pre12==0, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw)*2 & rel==1& rural_pre12==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t3b_linear_2h.xls", replace;

****************** TABLE 4: Domestic violence outcomes;
*linear RD, h bandwidth, with controls;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

*OLS full sample;
foreach x in z_physical z_sexual  z_emotional z_financial {; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t4_ols_full.xls", replace;	


*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in z_physical z_sexual  z_emotional z_financial {; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t4_rd_full.xls", replace;	

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in z_physical z_sexual  z_emotional z_financial {; 

rdrobust `x' dif if rel==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t4_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in z_physical z_sexual  z_emotional z_financial {; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t4_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual   z_emotional z_financial{; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual   pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t4_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual   z_emotional z_financial {; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual   pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t4_rd2sls_rural.xls", replace;

****************** TABLE 5: Attitudes;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes{; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t5_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes {; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t5_rd_full.xls", replace;	

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes {; 

rdrobust `x' dif if rel==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t5_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes {; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t5_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes {; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t5_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes {; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t5_rd2sls_rural.xls", replace;

****************** TABLE 6: Labor market outcomes;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t6_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income {; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t6_rd_full.xls", replace;	

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in work_lastweek emp_nonagr service agriculture social_security z_income {; 

rdrobust `x' dif if rel==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t6_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t6_ols_rural.xls", replace;


*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income {; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t6_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income {; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t6_rd2sls_rural.xls", replace;


****************** TABLE 7: Partner characteristics;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t7_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{; 

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t7_rd_full.xls", replace;	

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{; 

rdrobust `x' dif if rel==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t7_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t7_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t7_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{; 

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1 & rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_t7_rd2sls_rural.xls", replace;

****************** TABLE A4;
*linear RD full sample;
use "created/women_data_for_analysis.dta", clear;
global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta4_linear_full.xls", replace;

*quadratic RD full sample;
use "created/women_data_for_analysis.dta", clear;
global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;
regress `x' after1986 di1* di2* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta4_quad_full.xls", replace;

*linear RD rural sample;
use "created/women_data_for_analysis.dta", clear;
global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<61 & rural_pre12==1&rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta4_linear_rural.xls", replace;

*quadratic RD rural sample;
use "created/women_data_for_analysis.dta", clear;
global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;
regress `x' after1986 di1* di2* $contr2 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta4_quad_rural.xls", replace;

*linear RD urban sample;
use "created/women_data_for_analysis.dta", clear;
global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<61 & rural_pre12==0&rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta4_linear_urban.xls", replace;

*quadratic RD urban sample;
use "created/women_data_for_analysis.dta", clear;
global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool{;
regress `x' after1986 di1* di2* $contr2 [aw=womenweight] if abs(dif)<61 & rural_pre12==0 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta4_quad_urban.xls", replace;



****************** TABLE A5: DOMESTIC VIOLENCE MEASURES;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional z_financial{; 

regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta5_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional  z_financial{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional  pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta5_rd_full.xls", replace;

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional  z_financial{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional  pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta5_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional  z_financial{;
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional  pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta5_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional  z_financial{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional  pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta5_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional  z_financial{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional  pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta5_rd2sls_rural.xls", replace;

****************** TABLE A6: ATTITUDES MEASURES;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes{; 

regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta6_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta6_rd_full.xls", replace;

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta6_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes{;
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta6_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta6_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in agree_notargue agree_spend agree_beat agree_division agree_childbeat agree_maleresponse agree_obligedsex z_attitudes{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_agree_notargue pval_agree_spend pval_agree_beat pval_agree_division pval_agree_childbeat pval_agree_maleresponse pval_agree_obligedsex pval_z_attitudes;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta6_rd2sls_rural.xls", replace;


****************** TABLE A7: LABOR MARKET MEASURES;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";	
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{; 

regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta7_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta7_rd_full.xls", replace;

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta7_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{;
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta7_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta7_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in work_lastweek emp_nonagr service agriculture social_security z_income{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_work_lastweek pval_emp_nonagr pval_service pval_agriculture pval_social_security pval_z_income;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta7_rd2sls_rural.xls", replace;



****************** TABLE A8;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{;
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta8_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta8_rd_full.xls", replace;

**RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta8_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{;
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta8_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{;
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta8_rd_rural.xls", replace;

**RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in marriage_age marriage_decision working_men schooling_partner schooling_gap age_gap husband_age z_malereligious motherinlaw_violence partnerfaceddv divorced second_marriage z_asset{;
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<61 & rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_marriage_age pval_marriage_decision pval_working_men pval_schooling_partner pval_schooling_gap pval_age_gap pval_husband_age pval_z_malereligious pval_motherinlaw_violence pval_partnerfaceddv pval_divorced pval_second_marriage pval_z_asset;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta8_rd2sls_rural.xls", replace;


****************** TABLE A11;
*linear RD, h bandwidth, with controls;
use "created/hlfs2014_for_graphs", clear;

global contr1="month_* region26_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if male==0, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=faktor] if abs(dif)<e(h_bw) & male==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta11_linear_h.xls", replace;

*quadratic RD, h bandwidth, with controls;
use "created/hlfs2014_for_graphs", clear;

global contr1="month_* region26_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if male==0, bwselect(IK);
regress `x' after1986 di1* di2* $contr1 [aw=faktor] if abs(dif)<e(h_bw) &  male==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta11_quad_h.xls", replace;

*linear RD, h/2 bandwidth, with controls;
use "created/hlfs2014_for_graphs", clear;

global contr1="month_* region26_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if male==0, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=faktor] if abs(dif)<e(h_bw)/2 & male==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta11_linear_h2.xls", replace;

*linear RD, h*2 bandwidth, with controls;
use "created/hlfs2014_for_graphs", clear;

global contr1="month_* region26_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";
foreach x in schooling jhighschool highschool primaryschool{;

rdrobust `x' dif if male==0, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=faktor] if abs(dif)<e(h_bw)*2 & male==0, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_highschool pval_primaryschool;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta11_linear_2h.xls", replace;


****************** TABLE A12;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in partner_reason_children partner_reason_disobey partner_reason_economic partner_reason_fidelity partner_reason_jealous partner_reason_pfamily partner_reason_sex partner_reason_wfamily partner_reason_wjealous{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_partner_reason_children pval_partner_reason_disobey pval_partner_reason_economic pval_partner_reason_fidelity pval_partner_reason_jealous pval_partner_reason_pfamily  pval_partner_reason_sex pval_partner_reason_wfamily pval_partner_reason_wjealous;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta12_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in partner_reason_children partner_reason_disobey partner_reason_economic partner_reason_fidelity partner_reason_jealous partner_reason_pfamily  partner_reason_sex partner_reason_wfamily partner_reason_wjealous{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_partner_reason_children pval_partner_reason_disobey pval_partner_reason_economic pval_partner_reason_fidelity pval_partner_reason_jealous pval_partner_reason_pfamily  pval_partner_reason_sex pval_partner_reason_wfamily pval_partner_reason_wjealous;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta12_rd_full.xls", replace;

*RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in partner_reason_children partner_reason_disobey partner_reason_economic partner_reason_fidelity partner_reason_jealous partner_reason_pfamily  partner_reason_sex partner_reason_wfamily partner_reason_wjealous{;

rdrobust `x' dif if rel==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_partner_reason_children pval_partner_reason_disobey pval_partner_reason_economic pval_partner_reason_fidelity pval_partner_reason_jealous pval_partner_reason_pfamily  pval_partner_reason_sex pval_partner_reason_wfamily pval_partner_reason_wjealous;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta12_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in partner_reason_children partner_reason_disobey partner_reason_economic partner_reason_fidelity partner_reason_jealous partner_reason_pfamily  partner_reason_sex partner_reason_wfamily partner_reason_wjealous{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_partner_reason_children pval_partner_reason_disobey pval_partner_reason_economic pval_partner_reason_fidelity pval_partner_reason_jealous pval_partner_reason_pfamily  pval_partner_reason_sex pval_partner_reason_wfamily pval_partner_reason_wjealous;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta12_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in partner_reason_children partner_reason_disobey partner_reason_economic partner_reason_fidelity partner_reason_jealous partner_reason_pfamily  partner_reason_sex partner_reason_wfamily partner_reason_wjealous{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_partner_reason_children pval_partner_reason_disobey pval_partner_reason_economic pval_partner_reason_fidelity pval_partner_reason_jealous pval_partner_reason_pfamily  pval_partner_reason_sex pval_partner_reason_wfamily pval_partner_reason_wjealous;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta12_rd_rural.xls", replace;

*RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in partner_reason_children partner_reason_disobey partner_reason_economic partner_reason_fidelity partner_reason_jealous partner_reason_pfamily  partner_reason_sex partner_reason_wfamily partner_reason_wjealous{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) &  rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_partner_reason_children pval_partner_reason_disobey pval_partner_reason_economic pval_partner_reason_fidelity pval_partner_reason_jealous pval_partner_reason_pfamily  pval_partner_reason_sex pval_partner_reason_wfamily pval_partner_reason_wjealous;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta12_rd2sls_rural.xls", replace;

**Table A13;
*OLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in num_children ever_given_birth ever_used_contraceptive partner_disapproves_contra{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_num_children pval_ever_given_birth pval_ever_used_contraceptive pval_partner_disapproves_contra;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta13_ols_full.xls", replace;

*RD full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in num_children ever_given_birth ever_used_contraceptive partner_disapproves_contra{;

rdrobust `x' dif if rel==1, bwselect(IK);
regress `x' after1986 di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_num_children pval_ever_given_birth pval_ever_used_contraceptive pval_partner_disapproves_contra;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta13_rd_full.xls", replace;

*RD-2SLS full sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in num_children ever_given_birth ever_used_contraceptive partner_disapproves_contra{;

rdrobust `x' dif if rel==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_num_children pval_ever_given_birth pval_ever_used_contraceptive pval_partner_disapproves_contra;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta13_rd2sls_full.xls", replace;

*OLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in num_children ever_given_birth ever_used_contraceptive partner_disapproves_contra{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' schooling $contr1 [aw=womenweight] if abs(dif)<e(h_bw) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_num_children pval_ever_given_birth pval_ever_used_contraceptive pval_partner_disapproves_contra;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta13_ols_rural.xls", replace;

*RD rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in num_children ever_given_birth ever_used_contraceptive partner_disapproves_contra{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
regress `x' after1986 di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_num_children pval_ever_given_birth pval_ever_used_contraceptive pval_partner_disapproves_contra;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta13_rd_rural.xls", replace;

*RD-2SLS rural sample;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in num_children ever_given_birth ever_used_contraceptive partner_disapproves_contra{;

rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(IK);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if abs(dif)<e(h_bw) &  rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_num_children pval_ever_given_birth pval_ever_used_contraceptive pval_partner_disapproves_contra;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta13_rd2sls_rural.xls", replace;

/*
****************** TABLE A9;
**Please install the following rdrobust command prior to running this section: net install rdrobust, from(http://www-personal.umich.edu/~cattaneo/software/rdrobust/stata) replace;
*OLS CCT;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional z_financial {;
rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(mserd) scaleregul(0);
regress `x' schooling $contr1 [aw=womenweight] if dif>-e(h_l) & dif<e(h_r) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta9_ols_cct.xls", replace;

*Reduced from CCT;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in schooling jhighschool z_physical z_sexual  z_emotional z_financial{;
rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(mserd) scaleregul(0);
regress `x' after1986 di1* $contr2 [aw=womenweight] if dif>-e(h_l) & dif<e(h_r) & rel==1& rural_pre12==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_schooling pval_jhighschool pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta9_rd_cct.xls", replace;

*IV CCT;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_physical z_sexual  z_emotional z_financial {;
rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(mserd) scaleregul(0);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if dif>-e(h_l) & dif<e(h_r) &  rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_physical pval_z_sexual  pval_z_emotional pval_z_financial;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta9_2sls_cct.xls", replace;


****************** TABLE A10;
**Please install the following rdrobust command prior to running this section: net install rdrobust, from(http://www-personal.umich.edu/~cattaneo/software/rdrobust/stata) replace;
*OLS CCT;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_attitudes work_lastweek emp_nonagr z_income schooling_partner working_men marriage_age motherinlaw_violence {;
rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(mserd) scaleregul(0);
regress `x' schooling $contr1 [aw=womenweight] if dif>-e(h_l) & dif<e(h_r) & rel==1& rural_pre12==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_attitudes pval_work_lastweek pval_emp_nonagr pval_z_income pval_schooling_partner pval_working_men pval_marriage_age pval_motherinlaw_violence;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta10_ols_cct.xls", replace;

*RF CCT;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_attitudes work_lastweek emp_nonagr z_income schooling_partner working_men marriage_age motherinlaw_violence {;
rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(mserd)scaleregul(0);
regress `x' after1986 di1* $contr2 [aw=womenweight] if dif>-e(h_l) & dif<e(h_r) & rural_pre12==1 & rel==1, vce($se);
test after1986;
gen pval_`x'=r(p);
};

keep pval_z_attitudes pval_work_lastweek pval_emp_nonagr pval_z_income pval_schooling_partner pval_working_men pval_marriage_age pval_motherinlaw_violence;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta10_rd_cct.xls", replace;

*IV CCT;
use "created/women_data_for_analysis.dta", clear;

global contr1="month_* noturkish region26_pre12_* rural_pre12";
global contr2="month_* noturkish region26_pre12_* rural";
global se "cluster modate";
global slvl "starlevels(* 0.10 ** 0.05 *** 0.01)";

foreach x in z_attitudes work_lastweek emp_nonagr z_income schooling_partner working_men marriage_age motherinlaw_violence {;
rdrobust `x' dif if rel==1& rural_pre12==1, bwselect(mserd) scaleregul(0);
ivregress 2sls `x' (schooling=after1986) di1* $contr2 [aw=womenweight] if dif>-e(h_l) & dif<e(h_r) &  rural_pre12==1 & rel==1, vce($se);
test schooling;
gen pval_`x'=r(p);
};

keep pval_z_attitudes pval_work_lastweek pval_emp_nonagr pval_z_income pval_schooling_partner pval_working_men pval_marriage_age pval_motherinlaw_violence;
keep if _n==1;
xpose, clear varname;
rename v1 p;
rename _varname var;
qqvalue p, method(simes) qvalue(p_simes);
outsheet var p_simes if var!="" using "output/p_corr_ta10_2sls_cct.xls", replace;



